==> jc-1.4.0.tar.gz: soot/coffi/LocalVariableTable__5fattribute.h <==
// class soot.coffi.LocalVariableTable_attribute

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 97b2580188bb861f soot_coffi_LocalVariableTable__5fattribute
// @dep_class 49e6b7ec550acdca soot_coffi_attribute__5finfo

// header file dependencies
// @dep_header soot_coffi_attribute__5finfo

#include "soot/coffi/attribute__5finfo.h"

#ifndef _JC_soot_coffi_LocalVariableTable__5fattribute_H_
#define _JC_soot_coffi_LocalVariableTable__5fattribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_LocalVariableTable__5fattribute$sub_refs	_jc_soot_coffi_LocalVariableTable__5fattribute$sub_refs;
typedef struct _jc_soot_coffi_LocalVariableTable__5fattribute$sub_nonrefs	_jc_soot_coffi_LocalVariableTable__5fattribute$sub_nonrefs;
typedef struct _jc_soot_coffi_LocalVariableTable__5fattribute$refs	_jc_soot_coffi_LocalVariableTable__5fattribute$refs;
typedef struct _jc_soot_coffi_LocalVariableTable__5fattribute$nonrefs	_jc_soot_coffi_LocalVariableTable__5fattribute$nonrefs;
typedef struct _jc_soot_coffi_LocalVariableTable__5fattribute$object	_jc_soot_coffi_LocalVariableTable__5fattribute$object;

typedef const struct _jc_soot_coffi_LocalVariableTable__5fattribute$vmethods	_jc_soot_coffi_LocalVariableTable__5fattribute$vmethods;
typedef const struct _jc_soot_coffi_LocalVariableTable__5fattribute$vtable	_jc_soot_coffi_LocalVariableTable__5fattribute$vtable;
typedef const struct _jc_soot_coffi_LocalVariableTable__5fattribute$vtype	_jc_soot_coffi_LocalVariableTable__5fattribute$vtype;

// Constructors
extern void _jc_soot_coffi_LocalVariableTable__5fattribute$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_LocalVariableTable__5fattribute$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_coffi_LocalVariableTable__5fattribute$method$getLocalVariableName$894c1b4beebffff6(_jc_env *, struct _jc_soot_coffi_LocalVariableTable__5fattribute$object *, struct _jc_object_array *, jint);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_LocalVariableTable__5fattribute$method$getLocalVariableName$ce34191cd4257b91(_jc_env *, struct _jc_soot_coffi_LocalVariableTable__5fattribute$object *, struct _jc_object_array *, jint, jint);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_LocalVariableTable__5fattribute$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_coffi_LocalVariableTable__5fattribute$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_LocalVariableTable__5fattribute$method_info$getLocalVariableName$894c1b4beebffff6;
extern _jc_method _jc_soot_coffi_LocalVariableTable__5fattribute$method_info$getLocalVariableName$ce34191cd4257b91;
extern _jc_method _jc_soot_coffi_LocalVariableTable__5fattribute$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_coffi_LocalVariableTable__5fattribute$vmethods {
	struct _jc_java_lang_String$object	*(*getLocalVariableName$894c1b4beebffff6)(_jc_env *, struct _jc_soot_coffi_LocalVariableTable__5fattribute$object *, struct _jc_object_array *, jint);
	struct _jc_java_lang_String$object	*(*getLocalVariableName$ce34191cd4257b91)(_jc_env *, struct _jc_soot_coffi_LocalVariableTable__5fattribute$object *, struct _jc_object_array *, jint, jint);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_coffi_LocalVariableTable__5fattribute$object *);
};

// Vtable
struct _jc_soot_coffi_LocalVariableTable__5fattribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_attribute__5finfo$vmethods	soot_coffi_attribute__5finfo;
	_jc_soot_coffi_LocalVariableTable__5fattribute$vmethods	soot_coffi_LocalVariableTable__5fattribute;
};

// Vtype
struct _jc_soot_coffi_LocalVariableTable__5fattribute$vtype {
	_jc_type			type;
	_jc_soot_coffi_LocalVariableTable__5fattribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_LocalVariableTable__5fattribute$sub_refs {
	_jc_object_array	*local__5fvariable__5ftable;
};

// Reference instance fields (object)
struct _jc_soot_coffi_LocalVariableTable__5fattribute$refs {
    _jc_soot_coffi_LocalVariableTable__5fattribute$sub_refs	soot_coffi_LocalVariableTable__5fattribute;
    _jc_soot_coffi_attribute__5finfo$sub_refs	soot_coffi_attribute__5finfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_LocalVariableTable__5fattribute$sub_nonrefs {
	jint	local__5fvariable__5ftable__5flength;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_LocalVariableTable__5fattribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_attribute__5finfo$sub_nonrefs	soot_coffi_attribute__5finfo;
    _jc_soot_coffi_LocalVariableTable__5fattribute$sub_nonrefs	soot_coffi_LocalVariableTable__5fattribute;
};

// Object instance structure
struct _jc_soot_coffi_LocalVariableTable__5fattribute$object {
	_jc_soot_coffi_LocalVariableTable__5fattribute$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_LocalVariableTable__5fattribute$vtype	*vtype;
	_jc_soot_coffi_LocalVariableTable__5fattribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_LocalVariableTable__5fattribute$vtype _jc_soot_coffi_LocalVariableTable__5fattribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_LocalVariableTable__5fattribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_LocalVariableTable__5fattribute$class_object;

#endif	/* _JC_soot_coffi_LocalVariableTable__5fattribute_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/LocalVariableTable__5fattribute.h <==
// class soot.coffi.LocalVariableTable_attribute

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 97b2580188bb861f soot_coffi_LocalVariableTable__5fattribute
// @dep_class 49e6b7ec550acdca soot_coffi_attribute__5finfo

// header file dependencies
// @dep_header soot_coffi_attribute__5finfo

#include "soot/coffi/attribute__5finfo.h"

#ifndef _JC_soot_coffi_LocalVariableTable__5fattribute_H_
#define _JC_soot_coffi_LocalVariableTable__5fattribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_LocalVariableTable__5fattribute$sub_refs	_jc_soot_coffi_LocalVariableTable__5fattribute$sub_refs;
typedef struct _jc_soot_coffi_LocalVariableTable__5fattribute$sub_nonrefs	_jc_soot_coffi_LocalVariableTable__5fattribute$sub_nonrefs;
typedef struct _jc_soot_coffi_LocalVariableTable__5fattribute$refs	_jc_soot_coffi_LocalVariableTable__5fattribute$refs;
typedef struct _jc_soot_coffi_LocalVariableTable__5fattribute$nonrefs	_jc_soot_coffi_LocalVariableTable__5fattribute$nonrefs;
typedef struct _jc_soot_coffi_LocalVariableTable__5fattribute$object	_jc_soot_coffi_LocalVariableTable__5fattribute$object;

typedef const struct _jc_soot_coffi_LocalVariableTable__5fattribute$vmethods	_jc_soot_coffi_LocalVariableTable__5fattribute$vmethods;
typedef const struct _jc_soot_coffi_LocalVariableTable__5fattribute$vtable	_jc_soot_coffi_LocalVariableTable__5fattribute$vtable;
typedef const struct _jc_soot_coffi_LocalVariableTable__5fattribute$vtype	_jc_soot_coffi_LocalVariableTable__5fattribute$vtype;

// Constructors
extern void _jc_soot_coffi_LocalVariableTable__5fattribute$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_LocalVariableTable__5fattribute$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_coffi_LocalVariableTable__5fattribute$method$getLocalVariableName$894c1b4beebffff6(_jc_env *, struct _jc_soot_coffi_LocalVariableTable__5fattribute$object *, struct _jc_object_array *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_LocalVariableTable__5fattribute$method$getLocalVariableName$ce34191cd4257b91(_jc_env *, struct _jc_soot_coffi_LocalVariableTable__5fattribute$object *, struct _jc_object_array *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_LocalVariableTable__5fattribute$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_coffi_LocalVariableTable__5fattribute$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_LocalVariableTable__5fattribute$method_info$getLocalVariableName$894c1b4beebffff6;
extern _jc_method _jc_soot_coffi_LocalVariableTable__5fattribute$method_info$getLocalVariableName$ce34191cd4257b91;
extern _jc_method _jc_soot_coffi_LocalVariableTable__5fattribute$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_coffi_LocalVariableTable__5fattribute$vmethods {
	struct _jc_java_lang_String$object	*(*getLocalVariableName$894c1b4beebffff6)(_jc_env *, struct _jc_soot_coffi_LocalVariableTable__5fattribute$object *, struct _jc_object_array *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getLocalVariableName$ce34191cd4257b91)(_jc_env *, struct _jc_soot_coffi_LocalVariableTable__5fattribute$object *, struct _jc_object_array *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_coffi_LocalVariableTable__5fattribute$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_LocalVariableTable__5fattribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_attribute__5finfo$vmethods	soot_coffi_attribute__5finfo;
	_jc_soot_coffi_LocalVariableTable__5fattribute$vmethods	soot_coffi_LocalVariableTable__5fattribute;
};

// Vtype
struct _jc_soot_coffi_LocalVariableTable__5fattribute$vtype {
	_jc_type			type;
	_jc_soot_coffi_LocalVariableTable__5fattribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_LocalVariableTable__5fattribute$sub_refs {
	_jc_object_array	*local__5fvariable__5ftable;
};

// Reference instance fields (object)
struct _jc_soot_coffi_LocalVariableTable__5fattribute$refs {
    _jc_soot_coffi_LocalVariableTable__5fattribute$sub_refs	soot_coffi_LocalVariableTable__5fattribute;
    _jc_soot_coffi_attribute__5finfo$sub_refs	soot_coffi_attribute__5finfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_LocalVariableTable__5fattribute$sub_nonrefs {
	jint	local__5fvariable__5ftable__5flength;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_LocalVariableTable__5fattribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_attribute__5finfo$sub_nonrefs	soot_coffi_attribute__5finfo;
    _jc_soot_coffi_LocalVariableTable__5fattribute$sub_nonrefs	soot_coffi_LocalVariableTable__5fattribute;
};

// Object instance structure
struct _jc_soot_coffi_LocalVariableTable__5fattribute$object {
	_jc_soot_coffi_LocalVariableTable__5fattribute$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_LocalVariableTable__5fattribute$vtype	*vtype;
	_jc_soot_coffi_LocalVariableTable__5fattribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_LocalVariableTable__5fattribute$vtype _jc_soot_coffi_LocalVariableTable__5fattribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_LocalVariableTable__5fattribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_LocalVariableTable__5fattribute$class_object;

#endif	/* _JC_soot_coffi_LocalVariableTable__5fattribute_H_ */
